Research References
======================

This page lists research papers that have used the Unitary Computing Compiler (UCC) in their work.
If you have used UCC in your research, please let us know by `opening an issue or pull request <https://github.com/unitaryfoundation/ucc/issues/new?template=research_reference.md>`_ on GitHub to update this list.
If you are interested in using UCC for your research, please check out the `user guide <user_guide.rst>`_ and `contributing guide <contributing.rst>`_.

- :cite:t:`Du:2025dld` introduce CCMap, a modular circuit compiler designed for chip-to-chip coupler-connected quantum systems.
  CCMap improves the fidelity of circuits compiled by reducing costly inter-chip operations and applying noise-aware mapping.
  The authors benchmark their framework by integrating it with several existing compilers,including UCC, and demonstrate that CCMap enhances UCC's performance.
  UCC-CCMap achieved up to **17.8% higher fidelity** and **significant reductions in compilation cost** compared to UCC alone.

.. bibliography::
